#
# spec file for package reuse
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017 Free Software Foundation Europe e.V.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           reuse
Version:        4.0.3
Release:        1.2
Summary:        A tool for compliance with the REUSE recommendations
License:        Apache-2.0 AND CC-BY-SA-4.0 AND GPL-3.0-or-later AND CC0-1.0
Group:          Development/Languages/Python
URL:            https://git.fsfe.org/reuse/tool
Source:         https://files.pythonhosted.org/packages/source/r/reuse/reuse-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  git-core
BuildRequires:  python-rpm-macros
BuildRequires:  python3 >= 3.8
BuildRequires:  python3-Jinja2
BuildRequires:  python3-Sphinx
BuildRequires:  python3-binaryornot
BuildRequires:  python3-boolean.py
BuildRequires:  python3-debian
BuildRequires:  python3-freezegun
BuildRequires:  python3-license-expression
BuildRequires:  python3-myst-parser
BuildRequires:  python3-pip
BuildRequires:  python3-poetry
BuildRequires:  python3-pytest
BuildRequires:  python3-sphinxcontrib-apidoc
Requires:       python3 >= 3.8
Requires:       python3-Jinja2
Requires:       python3-attrs
Requires:       python3-binaryornot
Requires:       python3-boolean.py
Requires:       python3-debian
Requires:       python3-license-expression
Requires:       python3-tomlkit
Recommends:     git-core

%description
A tool for compliance with the REUSE recommendations.  Essentially,
it is a linter that checks for a project's compliance, and a compiler that
generates a project's bill of materials.

%prep
%setup -q -n reuse-%{version}

%build
%python3_pyproject_wheel
make -C docs man

%install
%python3_pyproject_install
%fdupes %{buildroot}%{python3_sitearch}
install -D -m 0644 docs/_build/man/*.1 -t "%{buildroot}%{_mandir}/man1/"

%check
PYTHONDONTWRITEBYTECODE=1 LC_ALL=C.UTF-8 LANG=C.UTF-8 py.test tests/

%files
%doc README.md CHANGELOG.md
%{_mandir}/man1/*.1%{ext_man}
%license LICENSES/*
%{_bindir}/reuse
%{python3_sitearch}/*

%changelog
* Fri Jul 19 2024 Matt Williams <matt@milliams.com>
- update to 4.0.3:
  * Fixed
    + Increased the minimum requirement of attrs to >=21.3. Older
    versions do not import correctly. (gh#fsfe/reuse-tool#1044)
- update to 4.0.2:
  * Fixed
    + Repaired a bug that would cause a crash when running annotate
  - -merge-copyrights on a file that does not yet have a year in
    the copyright statement. This bug was introduced in v4.0.1.
    (gh#fsfe/reuse-tool#1030)
- update to 4.0.1:
  * Fixed
    Make sure that Read the Docs can compile the documentation. This
    necesitated updating poetry.lock. (gh#fsfe/reuse-tool#1028)
- update to 4.0.0:
  * Added
    + Added support for REUSE.toml. (gh#fsfe/reuse-tool#863)
    + Added reuse convert-dep5 to convert .reuse/dep5 to REUSE.toml.
    (gh#fsfe/reuse-tool#863)
    + Man pages added for all reuse commands. Distribution
    maintainers might wish to distribute the (Sphinx-built) man
    pages. (gh#fsfe/reuse-tool#975)
    + More file types are recognised:
    + Assembler (.asm) (gh#fsfe/reuse-tool#928)
    + GraphQL (.graphqls, .gqls) (gh#fsfe/reuse-tool#930)
    + CUDA-C++ (.cu, .cuh) (gh#fsfe/reuse-tool#938)
    + Various .NET files (.csproj, .fsproj, .fsx, .props, .sln,
    .vbproj) (gh#fsfe/reuse-tool#940)
    + Cargo (Cargo.lock) (gh#fsfe/reuse-tool#937)
    + Clang-Tidy (.clang-tidy) (gh#fsfe/reuse-tool#961)
    + Java .properties files (gh#fsfe/reuse-tool#968)
    + Apache HTTP server config .htaccess files
    (gh#fsfe/reuse-tool#985)
    + npm .npmrc files (gh#fsfe/reuse-tool#985)
    + LaTeX class files (.cls) (gh#fsfe/reuse-tool#971)
    + CSON (.cson) (gh#fsfe/reuse-tool#1002)
    + Hjson (.hjson) (gh#fsfe/reuse-tool#1002)
    + JSON5 (.json5) (gh#fsfe/reuse-tool#1002)
    + JSON with Comments (.jsonc) (gh#fsfe/reuse-tool#1002)
    + Tap (.taprc) (gh#fsfe/reuse-tool#997)
    + Zsh (.zshrc) (gh#fsfe/reuse-tool#997)
    + Perl test (.t) (gh#fsfe/reuse-tool#997)
    + BATS test (.bats) (gh#fsfe/reuse-tool#997)
    + Octave/Matlab (.m) (gh#fsfe/reuse-tool#604)
    + VHDL(.vhdl) (gh#fsfe/reuse-tool#564)
    + Earthly files (Earthfile and .earthlyignore)
    (gh#fsfe/reuse-tool#1024)
    + Added comment styles:
    + man for UNIX Man pages (.man) (gh#fsfe/reuse-tool#954)
    + Added --lines output option for lint. (gh#fsfe/reuse-tool#956)
    + Treat %% !TEX and %% !BIB as shebangs in TeX and BibTeX files,
    respectively (gh#fsfe/reuse-tool#971)
    + Support alternate spelling --skip-unrecognized.
    (gh#fsfe/reuse-tool#974)
    + In annotate, rename --copyright-style to --copyright-prefix.
    The former parameter is still supported.
    (gh#fsfe/reuse-tool#973)
    + Support alternate spelling --skip-unrecognized
    (gh#fsfe/reuse-tool#974)
    + cpp and cppsingle style shorthands (see changes).
    (gh#fsfe/reuse-tool#941)
  * Changed
    + Updated SPDX resources to 3.24.0. (gh#fsfe/reuse-tool#994)
    + Updated REUSE specification version to 3.2.
    (gh#fsfe/reuse-tool#994)
    + .s files now use the Python comment style as per GNU Assembler
    (gas). (gh#fsfe/reuse-tool#928)
    + Previously, any file that begins with COPYING or LICENSE was
    ignored. This has been changed. Now, files like COPYING_README
    are no longer ignored, but COPYING and COPYING.txt are still
    ignored (in other words: exact matches, or COPYING + a file
    extension). Idem ditto for LICENSE. (gh#fsfe/reuse-tool#886)
    + Dependencies added:
    + attrs>=21.1 (gh#fsfe/reuse-tool#863)
    + tomlkit>=0.8 (gh#fsfe/reuse-tool#863)
    + Reorganised the way that c, css, and csingle styles work.
    (#941)
    + c used to support multi-line comments; it now only supports
    multi-line /* */ comments. This is identical to the old css
    style.
    + cpp has been added, which supports multi-line /* */ comments
    and single-line // comments. This is identical to the old c
    style.
    + csingle has been renamed to cppsingle, and it supports only
    single-line // comments.
  * Deprecated
    + .reuse/dep5 is marked deprecated. reuse convert-dep5 will help
    you switch to REUSE.toml. (gh#fsfe/reuse-tool#863)
  * Removed
    + The PendingDeprecationWarning for the aggregation of
    information between DEP5 and the contents of a file has been
    removed. This behaviour is now explicitly specified in REUSE
    Specification v3.2. (gh#fsfe/reuse-tool#1017, related to
    gh#fsfe/reuse-tool#779)
    + reuse init removed. (gh#fsfe/reuse-tool#863)
    + csingle and css style shorthands (see changes).
    (gh#fsfe/reuse-tool#941)
  * Fixed
    + The datetime value for Created: was wrongly formatted since
    3.0.0. It now returns a correctly formatted ISO 8601 date
    again. (gh#fsfe/reuse-tool#952)
    + Repaired the behaviour of reuse download where being inside of
    a LICENSES/ directory should not create a deeper
    LICENSES/LICENSES/ directory. (gh#fsfe/reuse-tool#975)
    + Support annotating a file that contains only a shebang.
    (gh#fsfe/reuse-tool#965)
    + Add CONTRIBUTING.md to the sdist. (gh#fsfe/reuse-tool#987)
    + In reuse spdx, fixed the output to be more compliant by
    capitalising SPDXRef-Document DESCRIBES appropriately.
    (gh#fsfe/reuse-tool#1013)
* Sun May  5 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.2:
  * `annotate`'s '`--style` now works again when used for a file
    with an unrecognised extension.
* Thu Mar 21 2024 Gordon Leung <pirateclip@protonmail.com>
- Set requires from git to git-core
* Sun Jan 28 2024 Dirk Müller <dmueller@suse.com>
- update to 3.0.1:
  * `.qrc` and `.ui` now have the HTML comment style instead of
    being marked uncommentable.
  * This reverts behaviour introduced in v3.0.0: the contents of
    uncommentable * files are scanned for REUSE information again.
    The contents of binary files are not.
  * Implement handling LicenseRef in `download` and `init`.
  * Declared support for Python 3.12.
  * More file types are recognised:
    + TCL (`.tcl`)
    + Julia (`.jl`)
    + Modern Fortran (`.f90`)
    + Bazel (`.bzl`)
    + GNU Linker script (`.ld`)
    + Assembly code (`.s`)
    + Empty placeholders (`.empty`)
    + ShellCheck configuration (`.shellcheckrc`)
    + Pylint in-project configuration (`pylintrc`)
    + Lisp schemes (`.sld`, `.sls`, `.sps`)
  + Added comment styles:
  * `csingle` for Zig (`.zig`) and Hare (`.ha`)
  * Display recommendations for steps to fix found issues during
    a lint.
  * Add support for Pijul VCS. Pijul support is not added to the
    Docker image.
  * When running `annotate` on a file with an unrecognised file
    path, the tool currently exits early. To automatically
    create a .license file for unrecognised files,
    `--fallback-dot-license` has been added.
  * Ignore `.sl` directory as used by Sapling SCM.
  * Alpine Docker image now uses 3.18 as base.
  * The Git submodule detection was made less naïve. Where
    previously it detected
  * a directory with a `.git` file as a submodule, it now uses
    the git command to detect submodules. This helps detect
    (quoted from Git man page) "[repositories] that were cloned
    independently and later added as a submodule or old setups",
    which "have the submodule's git directory inside the submodule
    instead of embedded into the superproject's git directory".
  * No longer scan binary or uncommentable files for their
    contents in search of REUSE information.
  * `--force-dot-license` and `--skip-unrecognised` are now
    mutually exclusive on `annotate`.
  * No longer create and publish `-extra` Docker images. The
    `openssh-client` package is now in the main image.
  * No longer create and publish `dev` Docker images.
  * The `-debian` Docker image is now based off debian:12-slim.
    It used to be based on the python:slim image, which used
    debian:slim under the hood.
  * Removed deprecated `--explicit-license`.
  * Removed deprecated `addheader`.
  * No longer depend on `sphinx-autodoc-typehints` for
    documentation.
  * Syntax errors in .reuse/dep5 now have better error handling.
  * Reduced python-debian minimum version to 0.1.34.
  * Fix issue in `annotate` where `--single-line` and `--multi-
    line` would not correctly raise an error with an incompatible
    comment style
  * Fix parsing existing copyright lines when they do not have a
    year
  * Better handling of Lisp comment styles. Now, any number of
    ";" characters is
  * recognised as the prefix to a Lisp comment, and ";;;" is used
    when inserting comment headers
* Tue Aug  1 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 2.1.0:
  * Added
    + Detect SPDX snippet tags in files. (gh#fsfe/reuse-tool#699)
    + More file types are recognised:
    + Fennel (`.fnl`) (gh#fsfe/reuse-tool#638)
    + CommonJS (`.cjs`) (gh#fsfe/reuse-tool#632)
    + Qt .pro (`.pro`) (gh#fsfe/reuse-tool#632)
    + Qt .pri (`.pri`) (gh#fsfe/reuse-tool#755)
    + Qt .qrc (`.qrc`) (gh#fsfe/reuse-tool#755)
    + Qt .qss(`.qss`) (gh#fsfe/reuse-tool#755)
    + Qt .ui (`.ui`) (gh#fsfe/reuse-tool#755)
    + Textile (`.textile`) (gh#fsfe/reuse-tool##712)
    + Visual Studio Code workspace (`.code-workspace`) (gh#fsfe/reuse-tool#747)
    + Application Resource Bundle (`.arb`) (gh#fsfe/reuse-tool#749)
    + Svelte components (`.svelte`)
    + AES encrypted files (`.aes`) (gh#fsfe/reuse-tool#758)
    + Jakarte Server Page (`.jsp`) (gh#fsfe/reuse-tool#757)
    + Clang format (`.clang-format`) (gh#fsfe/reuse-tool#632)
    + Browserslist config (`.browserslist`)
    + Prettier config (`.prettierrc`) and ignored files (`.prettierignore`)
    + Flutter pubspec.lock (`pubspec.lock`) (gh#fsfe/reuse-tool#751)
    + Flutter .metadata (`.metadata`) (gh#fsfe/reuse-tool#751)
    + Terraform (`.tf`, `tfvars`) and HCL (`.hcl`). (gh#fsfe/reuse-tool#756)
    + Typst (`.typ`)
    + Added loglevel argument to pytest and skip one test if loglevel is too high
    (gh#fsfe/reuse-tool#645).
    + `--add-license-concluded`, `--creator-person`, and `--creator-organization`
    added to `reuse spdx`. (gh#fsfe/reuse-tool#623)
    + Additional license metadata for the Python package has been added. The actual
    SPDX license expression remains the same:
    `Apache-2.0 AND CC0-1.0 AND CC-BY-SA-4.0 AND GPL-3.0-or-later`.
    (gh#fsfe/reuse-tool#733)
    + Added `--contributor` option to `annotate`. (gh#fsfe/reuse-tool#669)
    + Added `--json` flag to `lint` command (gh#fsfe/reuse-tool#654).
    + `reuse.ReuseInfo` now has `copy` and `union` methods. (gh#fsfe/reuse-tool#759)
    + `reuse.ReuseInfo` now stores information about the source from which the
    information was gathered. (gh#fsfe/reuse-tool#654, gh#fsfe/reuse-tool#787)
    + Added Ukrainian and Czech translations (gh#fsfe/reuse-tool#767)
    + Added `--suppress-deprecation` to hide (verbose) deprecation warnings.
    (gh#fsfe/reuse-tool#778)
  * Changed
    + Bumped SPDX license list to v3.20. (gh#fsfe/reuse-tool#692)
    + `reuse.SpdxInfo` was renamed to `reuse.ReuseInfo`. It is now a (frozen)
    dataclass instead of a namedtuple. This is only relevant if you're using reuse
    as a library in Python. Other functions and methods were similarly renamed.
    (gh#fsfe/reuse-tool#669)
    + Sphinx documentation: Switched from RTD theme to Furo. (gh#fsfe/reuse-tool#673,
    gh#fsfe/reuse-tool#716)
    + Removed dependency on setuptools' `pkg_resources` to determine the installed
    version of reuse. (gh#fsfe/reuse-tool#724)
    + Bumped SPDX license list to v3.21. (gh#fsfe/reuse-tool#763)
    + `Project.reuse_info_of` now returns a list of `ReuseInfo` objects instead of a
    single one. This is because the source information is now stored alongside the
    REUSE information. (gh#fsfe/reuse-tool#787)
  * Deprecated
    + Pending deprecation of aggregation of file sources. Presently, when copyright
    and licensing information is defined both within e.g. the file itself and in
    the DEP5 file, then the information is merged or aggregated for the purposes
    of linting and BOM generation. In the future, this will no longer be the case
    unless explicitly defined. The exact mechanism for this is not yet concrete,
    but a `PendingDeprecationWarning` will be shown to the user to make them aware
    of this. (gh#fsfe/reuse-tool#778)
  * Removed
    + Python 3.6 and 3.7 support has been dropped. (gh#fsfe/reuse-tool#673,
    gh#fsfe/reuse-tool#759)
    + Removed runtime and build time dependency on `setuptools`.
    (gh#fsfe/reuse-tool#724)
  * Fixed
    + Fixed automatic generation of Sphinx documentation via readthedocs.io by
    adding a `.readthedocs.yaml` configuration file (gh#fsfe/reuse-tool##648)
    + Fixed a compatibility issue where reuse could not be installed (built) if
    gettext is not installed. (gh#fsfe/reuse-tool##691)
    + Translations are available in Docker images. (gh#fsfe/reuse-tool##701)
    + Marked the `/data` directory in Docker containers as safe in Git, preventing
    errors related to linting Git repositories. (gh#fsfe/reuse-tool##720)
    + Repaired error when using Galician translations. (gh#fsfe/reuse-tool##719)
- Version 2.0.0: This version was yanked.
* Wed Apr  5 2023 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 1.1.2:
  * It is now possible/easier to use the `build` module to build this module.
    Previously, there was a namespace conflict (gh#fsfe/reuse-tool#640).
- Changes of 1.1.1:
  * Don't include documentation files (e.g. `README.md`) in top-level (i.e.,
    `site-packages/`) (gh#fsfe/reuse-tool#657).
  * Include documentation directory in sdist
    (gh#fsfe/reuse-tool#657).
- Changes of 1.1.0:
  * Added support for Python 3.11 (gh#fsfe/reuse-tool#603).
  * More file types are recognised:
    + Kotlin script (`.kts`)
    + Android Interface Definition Language (`.aidl`)
    + Certificate files (`.pem`)
  * Added comment styles:
    + Apache Velocity Template (Extensions: `.vm`, `.vtl`)
    (gh#fsfe/reuse-tool#554).
    + XQuery comment style (Extensions: `.xq(l|m|y|uery|)`)
    (gh#fsfe/reuse-tool#610).
  * Some special endings are always stripped from copyright and
    licensing statements (gh#fsfe/reuse-tool#602):
    + `">` (and variations such as `'>`, `" >`, and `"/>`)
    + `] ::`
  * Removed `setup.py` and replaced it with a Poetry configuration
    (gh#fsfe/reuse-tool#600).
  * Updated PyPI development status to 'production/stable'
    (gh#fsfe/reuse-tool#381).
  * The pre-commit hook now passes `lint` as an overridable argument
    (gh#fsfe/reuse-tool#574).
  * `addheader` has been renamed to `annotate`. The functionality remains the
    same (gh#fsfe/reuse-tool#550).
  * Bumped SPDX license list to v3.19.
  * `addheader` has been deprecated. It still works, but is now undocumented
    (gh#fsfe/reuse-tool#550).
  * Releases to PyPI are no longer GPG-signed. Support for this is not present
    in Poetry and not planned (gh#fsfe/reuse-tool#600).
  * Dependency on `requests` removed; using `urllib.request` from the standard
    library instead (gh#fsfe/reuse-tool#600).
  * Repair tests related to CVE-2022-39253 changes in upstream Git. New
    versions of Git no longer allow `git submodule add repository path` where
    repository is a file. A flag was added to explicitly allow this in the test
    framework (gh#fsfe/reuse-tool#619).
  * Sanitize xargs input in scripts documentation (gh#fsfe/reuse-tool#525).
  * License identifiers in comments with symmetrical ASCII art frames are now
    properly detected (gh#fsfe/reuse-tool#560)
  * Fixed an error where copyright statements contained within a multi-line
    comment style on a single line could not be parsed (gh#fsfe/reuse-tool#593).
  * In PHP files, add header after `<?php` (gh#fsfe/reuse-tool#543).
- Adapt spec file to poetry.
- Update URL.
* Fri Dec 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Allow git to use the file: protocol: add "git config --global
  protocol.file.allow always" to check section.
* Thu May 19 2022 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- update to 1.0.0:
  - Added the ability to ignore parts of a file when running `reuse lint`. Simply
    add `REUSE-IgnoreStart` and `REUSE-IgnoreEnd` as comments and all lines
    between the two will be ignored by the next run of `reuse lint`. (#463)
  - Meson subprojects are now ignored by default. (#496)
  - Added `--skip-existing` flag to `addheader` in order to skip files that
    already contain SPDX information. This may be useful for only adding SPDX
    information to newly created files. (#480)
  - Added `--recursive` flag to `addheader`. (#469)
  - Ignore all SPDX files with their typical formats and extensions. (#494)
  - Add support for merging copyright lines based on copyright statement,
    transforming multiple lines with a single year into a single line with a
    range. (#328)
  - Deprecated `--explicit-license` in favour of `--force-dot-license`.
    `--explicit-license` will remain useable (although undocumented) for the
    foreseeable future. (#476)
  - Better support for unary "+" operator in license identifiers. For example, if
    `Apache-1.0+` appears as a declared license, it should not be identified as
    missing, bad, or unused if `LICENSES/Apache-1.0.txt` exists. It is, however,
    identified separately as a used license. (#123)
  - When `addheader` creates a `.license` file, that file now has a newline at the
    end. (#477)
  - `supported-licenses` command that lists all licenses supported by REUSE (#401)
  - `--quiet` switch to the `lint` command (#402)
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.11.1:
  - Always write the output files encoded in UTF-8, explicitly. This is already the
    default on most Unix systems, but it was not on Windows.
  - All symlinks and 0-sized files in projects are now ignored.
  - The licenses CAL-1.0 and CAL-1.0-Combined-Work-Exception contain an SPDX tag
    within themselves. Files that are named after these licenses are now ignored.
  - Fixed a bug where `addheader` wouldn't properly apply the template on
    `.license` files if the `.license` file was non-empty, but did not contain
    valid SPDX tags.
  - Add support for autoconf comment style (listed as m4).
    + Cython (`.pyx`, `.pxd`)
    + Sass and SCSS (`.sass`, `.scss`)
    + XSL (`.xsl`)
    + Mailmap (`.mailmap`)
  - Added `--single-line` and `--multi-line` flags to `addheader`. These flags
    force a certain comment style.
  - Added support for Mercurial 4.3+.
  - A pre-commit hook has been added.
  - When an incorrect SPDX identifier is forwarded to `download` or `init`, the
    tool now suggests what you might have meant.
  - Under the hood, a lot of code that has to do with Git and Mercurial was moved
    into its own module.
  - Fixed a bug with `addheader --explicit-license` that would result in
    `file.license.license` if `file.license` already existed.
  - Fixed a Windows-only bug to do with calling subprocesses.
  - Fixed a rare bug that would trigger when a directory is both ignored and
    contains a `.git` file.
* Thu Jan 23 2020 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.8.0:
  + Performance improved with multiprocessing
  + New translations added for various different languages.
  + Can no longer lint subdirectories; must specify root with --root.
  + addheader supports many more file types.
  + Deprecated licenses are now recognised.
* Thu Nov 28 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.7.0:
  + Git submodules are ignored by default. Use --include-submodules
    to include them again.
  + Upstream name changed from fsfe-reuse to reuse.
  + addheader improvements.
* Thu Sep  5 2019 Carmen Bianca Bakker <carmen@carmenbianca.eu>
- Update to version 0.5.0:
  + The tool is now compliant with REUSE v3.0
* Wed Aug 15 2018 carmen@carmenbianca.eu
- Update to version 0.3.3:
  + Files ending in .spdx are no longer considered licenses.
* Tue Aug 14 2018 carmen@carmenbianca.eu
- Update to version 0.3.1:
  + Finding of root directory fixed when using pygit2.
* Wed May 16 2018 carmen@carmenbianca.eu
- Update to version 0.3.0:
  + Bill of materials output is now deterministic.  Entries are
    sorted.
* Tue Apr 17 2018 carmen@carmenbianca.eu
- Update to version 0.2.0:
  + Added translations for Dutch, Esperanto and Spanish.
  + Added new `-only` and `-or-later` SPDX tags for GPL.
  + Based on argparse instead of click.
- Remove xfail-test.patch.
* Tue Dec 19 2017 carmen@carmenbianca.eu
- Added package, version 0.1.1.
- Add xfail-test.patch to ignore a test that fails occasionally.
